# coding: utf-8

# flake8: noqa

"""
    QuePasa RAG SaaS API

    API for RAG retrieval, managing documents, files, and related operations including Telegram integration.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from quepasa.api.default_api import DefaultApi

# import ApiClient
from quepasa.api_response import ApiResponse
from quepasa.api_client import ApiClient
from quepasa.configuration import Configuration
from quepasa.exceptions import OpenApiException
from quepasa.exceptions import ApiTypeError
from quepasa.exceptions import ApiValueError
from quepasa.exceptions import ApiKeyError
from quepasa.exceptions import ApiAttributeError
from quepasa.exceptions import ApiException

# import models into sdk package
from quepasa.models.answer_detail import AnswerDetail
from quepasa.models.answer_detail_data import AnswerDetailData
from quepasa.models.answer_detail_data_labeled_links_value import AnswerDetailDataLabeledLinksValue
from quepasa.models.answer_detail_data_links_value import AnswerDetailDataLinksValue
from quepasa.models.batch_status import BatchStatus
from quepasa.models.batch_status_data import BatchStatusData
from quepasa.models.chunks_detail import ChunksDetail
from quepasa.models.chunks_detail_data_inner import ChunksDetailDataInner
from quepasa.models.created_batch_status import CreatedBatchStatus
from quepasa.models.created_batch_status_data import CreatedBatchStatusData
from quepasa.models.document import Document
from quepasa.models.document_detail import DocumentDetail
from quepasa.models.document_detail_data import DocumentDetailData
from quepasa.models.document_detail_data_pages_inner import DocumentDetailDataPagesInner
from quepasa.models.document_not_found import DocumentNotFound
from quepasa.models.document_pages_inner import DocumentPagesInner
from quepasa.models.domain_data_detail import DomainDataDetail
from quepasa.models.domain_detail import DomainDetail
from quepasa.models.domain_list_detail import DomainListDetail
from quepasa.models.operation_failed_status import OperationFailedStatus
from quepasa.models.retrieve_answer_request import RetrieveAnswerRequest
from quepasa.models.retrieve_answer_request_document_relevance_weights import RetrieveAnswerRequestDocumentRelevanceWeights
from quepasa.models.retrieve_answer_request_relevance_weights import RetrieveAnswerRequestRelevanceWeights
from quepasa.models.retrieve_answer_request_user_info import RetrieveAnswerRequestUserInfo
from quepasa.models.retrieve_chunks_request import RetrieveChunksRequest
from quepasa.models.setup_telegram_request import SetupTelegramRequest
from quepasa.models.setup_telegram_request_commands import SetupTelegramRequestCommands
from quepasa.models.setup_telegram_request_commands_ask import SetupTelegramRequestCommandsAsk
from quepasa.models.setup_telegram_request_commands_start import SetupTelegramRequestCommandsStart
from quepasa.models.telegram_status import TelegramStatus



# coding: utf-8

"""
    QuePasa RAG SaaS API

    API for RAG retrieval, managing documents, files, and related operations including Telegram integration.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from quepasa.models.document import Document

class TestDocument(unittest.TestCase):
    """Document unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Document:
        """Test Document
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Document`
        """
        model = Document()
        if include_optional:
            return Document(
                id = '',
                url = '',
                text = '',
                html = '',
                markdown = '',
                pages = [
                    quepasa.models.document_pages_inner.Document_pages_inner(
                        text = '', 
                        language = '', )
                    ],
                language = '',
                title = '',
                keywords = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return Document(
                id = '',
                url = '',
        )
        """

    def testDocument(self):
        """Test Document"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    QuePasa RAG SaaS API

    API for RAG retrieval, managing documents, files, and related operations including Telegram integration.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from quepasa.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_get_batch_status(self) -> None:
        """Test case for get_batch_status

        Get batch status
        """
        pass

    def test_get_document(self) -> None:
        """Test case for get_document

        Get document details
        """
        pass

    def test_list_all_documents(self) -> None:
        """Test case for list_all_documents

        List all documents
        """
        pass

    def test_list_documents(self) -> None:
        """Test case for list_documents

        List documents
        """
        pass

    def test_remove_document(self) -> None:
        """Test case for remove_document

        Remove document
        """
        pass

    def test_remove_domain(self) -> None:
        """Test case for remove_domain

        Remove domain
        """
        pass

    def test_replace_documents(self) -> None:
        """Test case for replace_documents

        Replace documents
        """
        pass

    def test_retrieve_answer(self) -> None:
        """Test case for retrieve_answer

        Retrieve answers
        """
        pass

    def test_retrieve_chunks(self) -> None:
        """Test case for retrieve_chunks

        Retrieve search results
        """
        pass

    def test_setup_telegram(self) -> None:
        """Test case for setup_telegram

        Setup Telegram integration
        """
        pass

    def test_upsert_documents(self) -> None:
        """Test case for upsert_documents

        Upsert documents
        """
        pass

    def test_upsert_files(self) -> None:
        """Test case for upsert_files

        Upsert files
        """
        pass

    def test_upsert_urls(self) -> None:
        """Test case for upsert_urls

        Upsert urls
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    QuePasa RAG SaaS API

    API for RAG retrieval, managing documents, files, and related operations including Telegram integration.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from quepasa.models.document_detail import DocumentDetail

class TestDocumentDetail(unittest.TestCase):
    """DocumentDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocumentDetail:
        """Test DocumentDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocumentDetail`
        """
        model = DocumentDetail()
        if include_optional:
            return DocumentDetail(
                status = '',
                data = quepasa.models.document_detail_data.DocumentDetail_data(
                    id = '', 
                    url = '', 
                    domain = '', 
                    title = '', 
                    keywords = '', 
                    pages = [
                        quepasa.models.document_detail_data_pages_inner.DocumentDetail_data_pages_inner(
                            text = '', 
                            language = '', 
                            keywords = '', )
                        ], 
                    languages = [
                        ''
                        ], 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return DocumentDetail(
                status = '',
                data = quepasa.models.document_detail_data.DocumentDetail_data(
                    id = '', 
                    url = '', 
                    domain = '', 
                    title = '', 
                    keywords = '', 
                    pages = [
                        quepasa.models.document_detail_data_pages_inner.DocumentDetail_data_pages_inner(
                            text = '', 
                            language = '', 
                            keywords = '', )
                        ], 
                    languages = [
                        ''
                        ], 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testDocumentDetail(self):
        """Test DocumentDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    QuePasa RAG SaaS API

    API for RAG retrieval, managing documents, files, and related operations including Telegram integration.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from quepasa.models.retrieve_answer_request_document_relevance_weights import RetrieveAnswerRequestDocumentRelevanceWeights
from quepasa.models.retrieve_answer_request_relevance_weights import RetrieveAnswerRequestRelevanceWeights
from quepasa.models.retrieve_answer_request_user_info import RetrieveAnswerRequestUserInfo
from typing import Optional, Set
from typing_extensions import Self

class RetrieveChunksRequest(BaseModel):
    """
    RetrieveChunksRequest
    """ # noqa: E501
    question: Optional[StrictStr] = Field(default=None, description="Natural language query to retrieve or answer.")
    domain: Optional[StrictStr] = Field(default=None, description="The name of a group of documents.")
    kind: Optional[StrictStr] = Field(default=None, description="(Experimental) Specifies the type of chunk. Can be \"text\" for raw text chunks, \"summary\" for chunks that are summaries of raw text, or \"all\" to include both types.")
    relevance_weights: Optional[RetrieveAnswerRequestRelevanceWeights] = None
    document_relevance_weights: Optional[RetrieveAnswerRequestDocumentRelevanceWeights] = None
    chunk_relevance_weights: Optional[RetrieveAnswerRequestDocumentRelevanceWeights] = None
    reranker_prompt: Optional[StrictStr] = Field(default=None, description="A prompt template used by the reranking model to prioritize and reorder both documents and chunks based on their relevance to a query. This prompt guides the model in assessing the importance of each document and refining the ranking output. ")
    document_reranker_prompt: Optional[StrictStr] = Field(default=None, description="A prompt template used by the reranking model to prioritize and reorder documents based on their relevance to a query. This prompt guides the model in assessing the importance of each document and refining the ranking output. ")
    chunk_reranker_prompt: Optional[StrictStr] = Field(default=None, description="A prompt template used by the reranking model to prioritize and reorder chunks based on their relevance to a query. This prompt guides the model in assessing the importance of each document and refining the ranking output. ")
    user_info: Optional[RetrieveAnswerRequestUserInfo] = None
    __properties: ClassVar[List[str]] = ["question", "domain", "kind", "relevance_weights", "document_relevance_weights", "chunk_relevance_weights", "reranker_prompt", "document_reranker_prompt", "chunk_reranker_prompt", "user_info"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RetrieveChunksRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of relevance_weights
        if self.relevance_weights:
            _dict['relevance_weights'] = self.relevance_weights.to_dict()
        # override the default output from pydantic by calling `to_dict()` of document_relevance_weights
        if self.document_relevance_weights:
            _dict['document_relevance_weights'] = self.document_relevance_weights.to_dict()
        # override the default output from pydantic by calling `to_dict()` of chunk_relevance_weights
        if self.chunk_relevance_weights:
            _dict['chunk_relevance_weights'] = self.chunk_relevance_weights.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user_info
        if self.user_info:
            _dict['user_info'] = self.user_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RetrieveChunksRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "question": obj.get("question"),
            "domain": obj.get("domain"),
            "kind": obj.get("kind"),
            "relevance_weights": RetrieveAnswerRequestRelevanceWeights.from_dict(obj["relevance_weights"]) if obj.get("relevance_weights") is not None else None,
            "document_relevance_weights": RetrieveAnswerRequestDocumentRelevanceWeights.from_dict(obj["document_relevance_weights"]) if obj.get("document_relevance_weights") is not None else None,
            "chunk_relevance_weights": RetrieveAnswerRequestDocumentRelevanceWeights.from_dict(obj["chunk_relevance_weights"]) if obj.get("chunk_relevance_weights") is not None else None,
            "reranker_prompt": obj.get("reranker_prompt"),
            "document_reranker_prompt": obj.get("document_reranker_prompt"),
            "chunk_reranker_prompt": obj.get("chunk_reranker_prompt"),
            "user_info": RetrieveAnswerRequestUserInfo.from_dict(obj["user_info"]) if obj.get("user_info") is not None else None
        })
        return _obj


